==> caf_toolkit-0.7.3.tar.gz: caf_toolkit-0.7.3/README.md <==

![Transport for the North Logo](https://github.com/Transport-for-the-North/caf.toolkit/blob/main/docs/TFN_Landscape_Colour_CMYK.png)

<h1 align="center">CAF.Toolkit</h1>

<p align="center">
<a href="https://pypi.org/project/caf.toolkit/"><img alt="Supported Python versions" src="https://img.shields.io/pypi/pyversions/caf.toolkit.svg?style=flat-square"></a>
<a href="https://pypi.org/project/caf.toolkit/"><img alt="Latest release" src="https://img.shields.io/github/release/transport-for-the-north/caf.toolkit.svg?style=flat-square&maxAge=86400"></a>
<a href="https://anaconda.org/conda-forge/caf.toolkit"><img alt="Conda" src="https://img.shields.io/conda/v/conda-forge/caf.toolkit?style=flat-square&logo=condaforge"></a>
<a href="https://app.codecov.io/gh/Transport-for-the-North/caf.toolkit"><img alt="Coverage" src="https://img.shields.io/codecov/c/github/transport-for-the-north/caf.toolkit.svg?branch=master&style=flat-square&logo=CodeCov"></a>
<a href="https://github.com/Transport-for-the-North/caf.toolkit/actions?query=event%3Apush"><img alt="Testing Badge" src="https://img.shields.io/github/actions/workflow/status/transport-for-the-north/caf.toolkit/tests.yml?style=flat-square&logo=GitHub&label=Tests"></a>
<a href='https://caftoolkit.readthedocs.io/en/stable/?badge=stable'><img alt='Documentation Status' src="https://img.shields.io/readthedocs/caftoolkit?style=flat-square&logo=readthedocs"></a>
<a href="https://github.com/psf/black"><img alt="code style: black" src="https://img.shields.io/badge/code%20format-black-000000.svg?style=flat-square"></a>
</p>



The Common Analytical Framework (CAF) Toolkit is a toolkit of transport
planning and appraisal functionalities. It's the beginning of a project to make
a lot of the useful stuff from
[NorMITs Demand](https://github.com/Transport-for-the-North/NorMITs-Demand)
more widely available and easily accessible.


## Contributing
CAF.Toolkit happily accepts contributions.

The best way to contribute to this project is to go to the issues tab and report bugs or submit a feature request. This helps CAF.Toolkit become more stable and full-featured. Please check the closed bugs before submitting a bug report to see if your question has already been answered.

==> caf_toolkit-0.9.0.tar.gz: caf_toolkit-0.9.0/README.md <==

![Transport for the North Logo](https://github.com/Transport-for-the-North/caf.toolkit/blob/main/docs/TFN_Landscape_Colour_CMYK.png)

<h1 align="center">CAF.Toolkit</h1>

<p align="center">
<a href="https://pypi.org/project/caf.toolkit/"><img alt="Supported Python versions" src="https://img.shields.io/pypi/pyversions/caf.toolkit.svg?style=flat-square"></a>
<a href="https://pypi.org/project/caf.toolkit/"><img alt="Latest release" src="https://img.shields.io/github/release/transport-for-the-north/caf.toolkit.svg?style=flat-square&maxAge=86400"></a>
<a href="https://anaconda.org/conda-forge/caf.toolkit"><img alt="Conda" src="https://img.shields.io/conda/v/conda-forge/caf.toolkit?style=flat-square&logo=condaforge"></a>
<a href="https://app.codecov.io/gh/Transport-for-the-North/caf.toolkit"><img alt="Coverage" src="https://img.shields.io/codecov/c/github/transport-for-the-north/caf.toolkit.svg?branch=master&style=flat-square&logo=CodeCov"></a>
<a href="https://github.com/Transport-for-the-North/caf.toolkit/actions?query=event%3Apush"><img alt="Testing Badge" src="https://img.shields.io/github/actions/workflow/status/transport-for-the-north/caf.toolkit/tests.yml?style=flat-square&logo=GitHub&label=Tests"></a>
<a href='https://caftoolkit.readthedocs.io/en/stable/?badge=stable'><img alt='Documentation Status' src="https://img.shields.io/readthedocs/caftoolkit?style=flat-square&logo=readthedocs"></a>
<a href="https://github.com/psf/black"><img alt="code style: black" src="https://img.shields.io/badge/code%20format-black-000000.svg?style=flat-square"></a>
</p>



The Common Analytical Framework (CAF) Toolkit is a toolkit of transport
planning and appraisal functionalities. It's the beginning of a project to make
a lot of the useful stuff from
[NorMITs Demand](https://github.com/Transport-for-the-North/NorMITs-Demand)
more widely available and easily accessible.

## Common Analytical Framework

This package is sits within the [Common Analytical Framework (CAF)](https://transport-for-the-north.github.io/caf_homepage/intro.html),
which is a collaboration between transport bodies in the UK to develop and maintain commonly used
transport analytics and appraisal tools.

## Contributing
CAF.Toolkit happily accepts contributions.

The best way to contribute to this project is to go to the [issues tab](https://github.com/Transport-for-the-North/caf.toolkit/issues)
to report bugs or submit feature requests. This helps CAF.toolkit become more
stable and full-featured. Please check the closed bugs before submitting a bug report to see if your
question has already been answered.

Please see our [contribution guidelines](https://github.com/Transport-for-the-North/.github/blob/main/CONTRIBUTING.rst)
for details on contributing to the codebase or documentation.
